/*
 * #%L
 * EUGene :: EUGene
 * 
 * $Id: ModelReader.java 1079 2011-06-28 09:15:23Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/eugene/tags/eugene-2.6/eugene/src/main/java/org/nuiton/eugene/ModelReader.java $
 * %%
 * Copyright (C) 2004 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

package org.nuiton.eugene;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.nuiton.eugene.models.Model;

import java.io.File;
import java.io.IOException;

/**
 * ModelReader TODO real doc :)
 * <p/>
 * Created: 26 oct. 2009
 *
 * @param <M> Model to create from reading input files
 * @author fdesbois <fdesbois@codelutin.com>
 * @version $Id: ModelReader.java 1079 2011-06-28 09:15:23Z tchemit $
 */
public abstract class ModelReader<M extends Model> {

    private static final Log log = LogFactory.getLog(ModelReader.class);

    /** Date of the las modification of any source files. */
    protected long lastModifiedSource;

    /**
     * A verbose flag to see more things.
     *
     * @since 2.3
     */
    protected boolean verbose;

    /**
     * A flag to load only safe things.
     * <p/>
     * Usefull to have a safe loading of a model and his properties file.
     *
     * @since 2.3
     */
    protected boolean strictLoading;

    /**
     * The provider of safe tag values and stereotypes.
     *
     * @since 2.3
     */
    protected ModelPropertiesUtil.ModelPropertiesProvider modelPropertiesProvider;

    public boolean isVerbose() {
        return verbose;
    }

    public void setVerbose(boolean verbose) {
        this.verbose = verbose;
    }

    public boolean isStrictLoading() {
        return strictLoading;
    }

    public void setStrictLoading(boolean strictLoading) {
        this.strictLoading = strictLoading;
    }

    protected void setLastModifiedSource(File... files) {
        for (File file : files) {
            if (file.lastModified() > getLastModifiedSource()) {
                lastModifiedSource = file.lastModified();

                if (log.isDebugEnabled()) {
                    log.debug("source date: " + lastModifiedSource
                              + " files[i] date: " + file.lastModified() +
                              "(" + file + ")");
                }
            }
        }
    }

    /** @return the last modified file source (says the newer incoming file) */
    public long getLastModifiedSource() {
        return lastModifiedSource;
    }

    /**
     * Read files to produce a memory model.
     *
     * @param file files to read
     * @return the new model builded from files
     * @throws IOException if any IO errors while reading files
     */
    public abstract M read(File... file) throws IOException;

    /**
     * @return the provider of controled tagvalues and stereotypes.
     * @since 2.3
     */
    public ModelPropertiesUtil.ModelPropertiesProvider getModelPropertiesProvider() {
        return modelPropertiesProvider;
    }

    /**
     * Sets the provider of tag values and stereotypes availables.
     *
     * @param modelPropertiesProvider the provider to use
     * @since 2.3
     */
    public void setModelPropertiesProvider(ModelPropertiesUtil.ModelPropertiesProvider modelPropertiesProvider) {
        this.modelPropertiesProvider = modelPropertiesProvider;
    }
}
